/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <log4cxx/spi/defaultrepositoryselector.h>

using namespace LOG4CXX_NS;
using namespace LOG4CXX_NS::spi;
using namespace LOG4CXX_NS::helpers;

struct DefaultRepositorySelector::DefaultRepositorySelectorPrivate
{
	LoggerRepositoryPtr repository;
};

DefaultRepositorySelector::DefaultRepositorySelector(const LoggerRepositoryPtr repository1)
	: m_priv(std::make_unique<DefaultRepositorySelectorPrivate>())
{
	m_priv->repository = repository1;
}

DefaultRepositorySelector::~DefaultRepositorySelector() {}

LoggerRepositoryPtr DefaultRepositorySelector::getLoggerRepository()
{
	return m_priv->repository;
}
